summaryrefslogtreecommitdiffstats
path: root/krita/core/kis_paintop.cc
diff options
context:
space:
mode:
Diffstat (limited to 'krita/core/kis_paintop.cc')
-rw-r--r--krita/core/kis_paintop.cc30
1 files changed, 15 insertions, 15 deletions
diff --git a/krita/core/kis_paintop.cc b/krita/core/kis_paintop.cc
index 4030e931..e00484f1 100644
--- a/krita/core/kis_paintop.cc
+++ b/krita/core/kis_paintop.cc
@@ -19,12 +19,12 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
-#include "qwidget.h"
+#include "tqwidget.h"
#include "kis_painter.h"
#include "kis_layer.h"
#include "kis_types.h"
#include "kis_paintop.h"
-#include "kis_alpha_mask.h"
+#include "kis_alpha_tqmask.h"
#include "kis_point.h"
#include "kis_colorspace.h"
#include "kis_global.h"
@@ -42,11 +42,11 @@ KisPaintOp::~KisPaintOp()
{
}
-KisPaintDeviceSP KisPaintOp::computeDab(KisAlphaMaskSP mask) {
- return computeDab(mask, m_painter->device()->colorSpace());
+KisPaintDeviceSP KisPaintOp::computeDab(KisAlphaMaskSP tqmask) {
+ return computeDab(tqmask, m_painter->device()->colorSpace());
}
-KisPaintDeviceSP KisPaintOp::computeDab(KisAlphaMaskSP mask, KisColorSpace *cs)
+KisPaintDeviceSP KisPaintOp::computeDab(KisAlphaMaskSP tqmask, KisColorSpace *cs)
{
// XXX: According to the SeaShore source, the Gimp uses a
// temporary layer the size of the layer that is being painted
@@ -63,22 +63,22 @@ KisPaintDeviceSP KisPaintOp::computeDab(KisAlphaMaskSP mask, KisColorSpace *cs)
KisColorSpace * colorSpace = m_dab->colorSpace();
- Q_INT32 pixelSize = colorSpace->pixelSize();
+ TQ_INT32 pixelSize = colorSpace->pixelSize();
- Q_INT32 maskWidth = mask->width();
- Q_INT32 maskHeight = mask->height();
+ TQ_INT32 tqmaskWidth = tqmask->width();
+ TQ_INT32 tqmaskHeight = tqmask->height();
// Convert the kiscolor to the right colorspace.
kc.convertTo(colorSpace);
- KisHLineIteratorPixel hiter = m_dab->createHLineIterator(0, 0, maskWidth, true);
- for (int y = 0; y < maskHeight; y++)
+ KisHLineIteratorPixel hiter = m_dab->createHLineIterator(0, 0, tqmaskWidth, true);
+ for (int y = 0; y < tqmaskHeight; y++)
{
int x=0;
while(! hiter.isDone())
{
- // XXX: Set mask
- colorSpace->setAlpha(kc.data(), mask->alphaAt(x++, y), 1);
+ // XXX: Set tqmask
+ colorSpace->setAlpha(kc.data(), tqmask->alphaAt(x++, y), 1);
memcpy(hiter.rawData(), kc.data(), pixelSize);
++hiter;
}
@@ -88,9 +88,9 @@ KisPaintDeviceSP KisPaintOp::computeDab(KisAlphaMaskSP mask, KisColorSpace *cs)
return m_dab;
}
-void KisPaintOp::splitCoordinate(double coordinate, Q_INT32 *whole, double *fraction)
+void KisPaintOp::splitCoordinate(double coordinate, TQ_INT32 *whole, double *fraction)
{
- Q_INT32 i = static_cast<Q_INT32>(coordinate);
+ TQ_INT32 i = static_cast<TQ_INT32>(coordinate);
if (coordinate < 0) {
// We always want the fractional part to be positive.
@@ -110,4 +110,4 @@ void KisPaintOp::setSource(KisPaintDeviceSP p) {
}
-KisPaintOpSettings* KisPaintOpFactory::settings(QWidget* /*parent*/, const KisInputDevice& /*inputDevice*/) { return 0; }
+KisPaintOpSettings* KisPaintOpFactory::settings(TQWidget* /*tqparent*/, const KisInputDevice& /*inputDevice*/) { return 0; }